==> knoda_0.7.orig.tar.gz: knoda-0.7.0.orig/hk_kdeclasses/hk_kdedatabasesetting.cpp <==
// ****************************************************************************
// copyright (c) 2000-2004 Horst Knorr <hk_classes@knoda.org>  
// This file is part of the hk_kdeclasses library.
// This file may be distributed and/or modified under the terms of the
// GNU Library Public License version 2 as published by the Free Software
// Foundation and appearing in the file LGPL included in the
// packaging of this file.
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// ****************************************************************************
 //$Revision: 1.2 $
#include "hk_kdedatabasesetting.h"
#include <klocale.h>
#include <kapplication.h>
#include <kaction.h>
#include <kiconloader.h>
#include <kstandarddirs.h>
#include <klistview.h>
#include <kcombobox.h>
#include <kpushbutton.h>

#include <qframe.h>
#include <qpixmap.h>
#include <qstringlist.h>
#include <qheader.h>

#include <hk_class.h>
#include <hk_database.h>


hk_kdedatabasesetting::hk_kdedatabasesetting( hk_database*db, QWidget* parent,  const char* name, bool modal, WFlags fl )
    : hk_kdedatabasesettingbase( parent, name, modal, fl )
{
 p_database=db;
 QStringList list;
 list.append(i18n("Local"));
 list.append(i18n("Central"));
 queryload->insertStringList(list);
 querystore->insertStringList(list);

 formload->insertStringList(list);
 formstore->insertStringList(list);

 reportload->insertStringList(list);
 reportstore->insertStringList(list);

 list.prepend("");
 allload->insertStringList(list);
 allstore->insertStringList(list);
   
  KIconLoader* loader=KGlobal::iconLoader();
  loader->addAppDir("hk_kdeclasses");

  KListViewItem* item= new KListViewItem(listview,i18n("Load/Save"));
  item->setPixmap(0,loader->loadIcon("filesave",KIcon::Desktop));
  item->setMultiLinesEnabled(true);
  listview->header()->setLabel( 0, "",listview->width() );
  if (!p_database) return;
  

  queryload->setCurrentItem(p_database->loadmode(ft_query)==hk_database::central?1:0);
  querystore->setCurrentItem(p_database->storagemode(ft_query)==hk_database::central?1:0);
  
  formload->setCurrentItem(p_database->loadmode(ft_form)==hk_database::central?1:0);
  formstore->setCurrentItem(p_database->storagemode(ft_form)==hk_database::central?1:0);
  
  reportload->setCurrentItem(p_database->loadmode(ft_report)==hk_database::central?1:0);
  reportstore->setCurrentItem(p_database->storagemode(ft_report)==hk_database::central?1:0);
  selection_changed();
  ok_button->setEnabled(false);
  
}

hk_kdedatabasesetting::~hk_kdedatabasesetting()
{
}


void hk_kdedatabasesetting::create_clicked()
{
  if (!p_database->create_centralstoragetable())
    {
      hk_class::show_warningmessage(hk_class::hk_translate("Error: could not create central storage table\n Check your permissions"));
      return;
    }
  selection_changed();
}

void hk_kdedatabasesetting::selection_changed()
{
bool hasstorage=p_database->has_centralstoragetable();
createbutton->setEnabled(!hasstorage);
storageframe->setEnabled(hasstorage);
ok_button->setEnabled(true);
}

void hk_kdedatabasesetting::alload_changed()
{
if (allload->currentItem()==0) return;
int p=allload->currentItem()-1;
queryload->setCurrentItem(p);
formload->setCurrentItem(p);
reportload->setCurrentItem(p);
ok_button->setEnabled(true);
}

void hk_kdedatabasesetting::allstore_changed()
{
if (allstore->currentItem()==0) return;
int p=allstore->currentItem()-1;
querystore->setCurrentItem(p);
formstore->setCurrentItem(p);
reportstore->setCurrentItem(p);
ok_button->setEnabled(true);

}



void hk_kdedatabasesetting::listview_changed()
{

}

void hk_kdedatabasesetting::ok_clicked()
{
 p_database->set_storagemode(ft_query, ((queryload->currentItem()==1)?hk_database::central:hk_database::local),
                                  ((querystore->currentItem()==1)?hk_database::central:hk_database::local));
 p_database->set_storagemode(ft_form, ((formload->currentItem()==1)?hk_database::central:hk_database::local),
                                  ((formstore->currentItem()==1)?hk_database::central:hk_database::local));
 p_database->set_storagemode(ft_report, ((reportload->currentItem()==1)?hk_database::central:hk_database::local),
                                  ((reportstore->currentItem()==1)?hk_database::central:hk_database::local));
  
 p_database->save_configuration(); 
 accept();
}

==> knoda_0.7.3.orig.tar.gz: knoda-0.7.3/hk_kdeclasses/hk_kdedatabasesetting.cpp <==
// ****************************************************************************
// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
// This file is part of the hk_kdeclasses library.
// This file may be distributed and/or modified under the terms of the
// GNU Library Public License version 2 as published by the Free Software
// Foundation and appearing in the file LGPL included in the
// packaging of this file.
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// ****************************************************************************
 //$Revision: 1.4 $
#include "hk_kdedatabasesetting.h"
#include <klocale.h>
#include <kapplication.h>
#include <kaction.h>
#include <kiconloader.h>
#include <kstandarddirs.h>
#include <klistview.h>
#include <kcombobox.h>
#include <kpushbutton.h>

#include <qframe.h>
#include <qpixmap.h>
#include <qstringlist.h>
#include <qheader.h>
#include <kapplication.h>
#include <kconfig.h>

#include <hk_class.h>
#include <hk_database.h>


hk_kdedatabasesetting::hk_kdedatabasesetting( hk_database*db, QWidget* parent,  const char* name, bool modal, WFlags fl )
    : hk_kdedatabasesettingbase( parent, name, modal, fl )
{
 p_database=db;
 QStringList list;
 list.append(i18n("Local"));
 list.append(i18n("Central"));
 queryload->insertStringList(list);
 querystore->insertStringList(list);

 formload->insertStringList(list);
 formstore->insertStringList(list);

 reportload->insertStringList(list);
 reportstore->insertStringList(list);

 list.prepend("");
 allload->insertStringList(list);
 allstore->insertStringList(list);
   
  KIconLoader* loader=KGlobal::iconLoader();
  loader->addAppDir("hk_kdeclasses");

  KListViewItem* item= new KListViewItem(listview,i18n("Load/Save"));
  item->setPixmap(0,loader->loadIcon("filesave",KIcon::Desktop));
  item->setMultiLinesEnabled(true);
  listview->header()->setLabel( 0, "",listview->width() );
  if (!p_database) return;
  

  queryload->setCurrentItem(p_database->loadmode(ft_query)==hk_database::central?1:0);
  querystore->setCurrentItem(p_database->storagemode(ft_query)==hk_database::central?1:0);
  
  formload->setCurrentItem(p_database->loadmode(ft_form)==hk_database::central?1:0);
  formstore->setCurrentItem(p_database->storagemode(ft_form)==hk_database::central?1:0);
  
  reportload->setCurrentItem(p_database->loadmode(ft_report)==hk_database::central?1:0);
  reportstore->setCurrentItem(p_database->storagemode(ft_report)==hk_database::central?1:0);
  selection_changed();
  ok_button->setEnabled(false);
 KConfig* c=kapp->config();
  QRect rect(0,0,500,300);
  c->setGroup("Databasesetting");
  QRect g;
  g=c->readRectEntry("Geometry",&rect);
  setGeometry(g);
  
}

hk_kdedatabasesetting::~hk_kdedatabasesetting()
{
}


void hk_kdedatabasesetting::create_clicked()
{
  if (!p_database->create_centralstoragetable())
    {
      hk_class::show_warningmessage(hk_class::hk_translate("Error: could not create central storage table\n Check your permissions"));
      return;
    }
  selection_changed();
}

void hk_kdedatabasesetting::selection_changed()
{
bool hasstorage=p_database->has_centralstoragetable();
createbutton->setEnabled(!hasstorage);
storageframe->setEnabled(hasstorage);
ok_button->setEnabled(true);
}

void hk_kdedatabasesetting::alload_changed()
{
if (allload->currentItem()==0) return;
int p=allload->currentItem()-1;
queryload->setCurrentItem(p);
formload->setCurrentItem(p);
reportload->setCurrentItem(p);
ok_button->setEnabled(true);
}

void hk_kdedatabasesetting::allstore_changed()
{
if (allstore->currentItem()==0) return;
int p=allstore->currentItem()-1;
querystore->setCurrentItem(p);
formstore->setCurrentItem(p);
reportstore->setCurrentItem(p);
ok_button->setEnabled(true);

}



void hk_kdedatabasesetting::listview_changed()
{

}

void hk_kdedatabasesetting::ok_clicked()
{
 p_database->set_storagemode(ft_query, ((queryload->currentItem()==1)?hk_database::central:hk_database::local),
                                  ((querystore->currentItem()==1)?hk_database::central:hk_database::local));
 p_database->set_storagemode(ft_form, ((formload->currentItem()==1)?hk_database::central:hk_database::local),
                                  ((formstore->currentItem()==1)?hk_database::central:hk_database::local));
 p_database->set_storagemode(ft_report, ((reportload->currentItem()==1)?hk_database::central:hk_database::local),
                                  ((reportstore->currentItem()==1)?hk_database::central:hk_database::local));
  
 p_database->save_configuration(); 
   KConfig* c=kapp->config();
    c->setGroup("Databasesetting");
    c->writeEntry("Geometry",geometry());
  accept();
}
